Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PubSub ¶
type PubSub struct {
// contains filtered or unexported fields
}
PubSub provides publish/subscribe functionality for real-time updates
func (*PubSub) GetSubscriberCount ¶
GetSubscriberCount returns the number of subscribers for a topic
func (*PubSub) Publish ¶
Publish sends a message to all subscribers of a topic. Uses a snapshot copy to avoid holding lock during potentially slow channel sends.
type Subscription ¶
type Subscription struct {
// contains filtered or unexported fields
}
Subscription represents a subscription to a topic
func (*Subscription) Channel ¶
func (s *Subscription) Channel() <-chan any
Channel returns the subscription's message channel
func (*Subscription) Unsubscribe ¶
func (s *Subscription) Unsubscribe()
Unsubscribe removes the subscription
Click to show internal directories.
Click to hide internal directories.